package guile;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);

require Exporter;
require DynaLoader;
require AutoLoader;

@ISA = qw(Exporter DynaLoader);
# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.
@EXPORT = qw(
	
);
$VERSION = '0.02';

bootstrap guile $VERSION;

# Preloaded methods go here.

# Autoload methods go after =cut, and are processed by the autosplit program.

1;
__END__
# Below is the stub of documentation for your module. You better edit it!

=head1 NAME

guile - Perl extension for embedding Guile Scheme interpreter

=head1 SYNOPSIS

  use guile;

  sub mainfunc {
    guile::eval("(+ 2 2)");
    guile::define("(define (plus x y) (+ x y))");
    ...
  }

  guile::main("mainfunc");

=head1 DESCRIPTION

This interface allow to easy embed C<Guile> in Perl programs. To use this
extension you must provide some sort of main function in your perl code.
This is because the C<Guile> interface requires that all the code that use
the interpeter must be in a function like the main() function of C<C>.
Thus the main Perl code must be enclosed in a function and the main
code become a call to the C<main> method specifying the name of the main
function.

=head1 FUNCTIONS

=over 4

=item main(MAIN_FUN)

This function starts the C<Scheme> interpreter and calls a Perl function
named C<MAIN_FUN>. When the C<MAIN_FUN> ends the Perl program is terminated.

=item eval(SCHEME_CODE)

This function must be invoked from the body of a C<MAIN_FUN> called by 
C<guile::main> function. The C<SCHEME_CODE> is evaluated and the result
is returned as a string.

=item define(SCHEME_CODE)

This function is equivalent to C<eval> but nothing is returned. It is
useful to make definitions into the C<Scheme>'s interpreter.

=back

=head1 AUTHOR

A. Cisternino, cisterni@di.unipi.it

=head1 SEE ALSO

perl(1).

=cut
